@@ -29,52 +29,40 @@
 #endif
 
 #include <unistd.h>
-#include <stdio.h>
 #include <string.h>
 #include "xMode.h"
 #include "pipsError.h"
-#include "ekpcom.h"
-
-/* locale setting */
-#include <stdlib.h>
 
 void *options[EX_N_OPT];
 void *opt_address[EX_N_OPT];
 char *input_file;
 char *output_file;
-char *atinput_file;
 int output_type;
 
-GtkWidget *margin_frame_;
 #if USE_GTK
-UTIL_PACK pips_util_pack;
+static void setDefaultOptions(SEP_INIT_PARAM*);
+static void finButtonSave(GtkWidget*, gpointer);
+static void finButtonOk(GtkWidget*, SEP_INIT_PARAM*);
+static void finButtonCanncel(GtkWidget*, gpointer);
+static GtkWidget* finButtonBoxNew(SEP_INIT_PARAM *);
 
-static void setDefaultOptions (SEP_INIT_PARAM*);
-static void finButtonSave (GtkWidget*, gpointer);
-static void finButtonOk (GtkWidget*, SEP_INIT_PARAM*);
-static void finButtonCanncel (GtkWidget*, gpointer);
-static GtkWidget* finButtonBoxNew (SEP_INIT_PARAM *);
-
-static GtkWidget* makeIoFrame (char*);
-static GtkWidget* makePaperFrame (char*);
-static GtkWidget* makeColorManagementFrame (char*);
-static GtkWidget* makeLayoutFrame (char*);
-static GtkWidget* makeAdvancedFrame (char*);
-static GtkWidget* makePropertyNotebook (void);
-static GtkWidget* makeUtilFrame (char *);
-static GtkWidget* makeConnectFrame (char*);
-static GtkWidget* makeNoConnectFrame (char*);
+static GtkWidget* makeIoFrame(char*);
+static GtkWidget* makePaperFrame(char*);
+static GtkWidget* makeColorManagementFrame(char*);
+static GtkWidget* makeAdvancedFrame(char*);
+static GtkWidget* makePropertyNotebook(void);
 #endif
 
-
 char*  getRscName(int id, int value)
 {
   int i, j;
 
-  for(i = 0; opt_all[i].id != id; i++);
-  for(j = 0; opt_all[i].data[j].value != END_ARRAY; j++)
-    if(opt_all[i].data[j].value == value)
-      return opt_all[i].data[j].rsc_name;
+  for (i = 0; opt_all[i].id != id; i++);
+  for (j = 0; opt_all[i].data[j].value != END_ARRAY; j++) {
+	  if (opt_all[i].data[j].value == value) {
+		  return opt_all[i].data[j].rsc_name;
+	  }
+  }
   return NULL;
 }
 
@@ -102,10 +90,6 @@ static void  setDefaultOptions(SEP_INIT_PARAM *sepip)
   *val = sepip->saturation;
 
   options[P_HALF_TONE] = getRscName(P_HALF_TONE, sepip->halftone_type);
-  
-  options[P_MICRO_WEAVE] = getRscName(P_MICRO_WEAVE, sepip->mw_type );
-  if(strcmp(options[P_MICRO_WEAVE], "ON")) options[P_MICRO_WEAVE] = NULL;
-
   options[P_HIGH_SPEED] = getRscName(P_HIGH_SPEED, sepip->high_speed);
   if(strcmp(options[P_HIGH_SPEED], "ON")) options[P_HIGH_SPEED] = NULL;
 
@@ -117,7 +101,10 @@ static void  setDefaultOptions(SEP_INIT_PARAM *sepip)
   *val= -(sepip->b_strength);
 
   options[P_QUALITY_LEVEL] = getRscName(P_QUALITY_LEVEL, sepip->qlevel);
+
+#ifdef ROLL_PAPER
   options[P_BIN] = getRscName(P_BIN, sepip->bin_id);
+#endif /* ROLL_PAPER */
 
 #ifdef CONV_VERSION2
   val = (int*)options[P_MARGIN_X];
@@ -125,17 +112,7 @@ static void  setDefaultOptions(SEP_INIT_PARAM *sepip)
   val = (int*)options[P_MARGIN_Y];
   *val = sepip->margin.y;
 #endif /* CONV_VERSION2 */
-  options[P_FIT_PAGE] = getRscName(P_FIT_PAGE, sepip->fit_page);
-  if(strcmp(options[P_FIT_PAGE], "ON")) options[P_FIT_PAGE] = NULL;
 
-  options[P_MULTI_PAGE] = getRscName(P_MULTI_PAGE, sepip->multi_page);
-  options[P_AUTO_CUT] = getRscName(P_AUTO_CUT, sepip->auto_cut);
-
-#ifdef INK_CHANGE_SYSTEM
-  options[P_INKSET] = getRscName(P_INKSET, sepip->inkset);
-#endif /* INK_CHANGE_SYSTEM */
-
-  return;
 }
 
 /*
@@ -156,15 +133,16 @@ static void finButtonOk(GtkWidget *widget, SEP_INIT_PARAM *sepip)
 
   if (getOptsForX (options, sepip))
     {
+      fprintf (stderr, "PIPS Error : option set error\n");
       return;
     }
 
 #ifdef CONV_VERSION2
   if (output_type)
     /* lprľή̣. version2ǤϤεǽϺͽ */
-    graphics_converter_version2 (sepip, input_file, ".", atinput_file); 
+    graphics_converter_version2 (sepip, input_file, "."); 
   else
-    graphics_converter_version2 (sepip, input_file, output_file, atinput_file);
+    graphics_converter_version2 (sepip, input_file, output_file);
 #else
 
   if (output_type) outfp = popen (SPOOLER_PATH, "w");
@@ -201,19 +179,19 @@ static GtkWidget* finButtonBoxNew(SEP_INIT_PARAM *sepip)
 
   hbox =  gtk_hbox_new(TRUE, GTK_BORDER);
   
-  button = gtk_button_new_with_label((char*)_(finishButtonLabels[0]));
+  button = gtk_button_new_with_label(_(finishButtonLabels[0]));
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		     GTK_SIGNAL_FUNC(finButtonSave), NULL);
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 5);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label((char*)_(finishButtonLabels[1]));
+  button = gtk_button_new_with_label(_(finishButtonLabels[1]));
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		     GTK_SIGNAL_FUNC(finButtonOk), sepip);
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 5);
   gtk_widget_show(button);
 
-  button = gtk_button_new_with_label((char*)_(finishButtonLabels[2]));
+  button = gtk_button_new_with_label(_(finishButtonLabels[2]));
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		     GTK_SIGNAL_FUNC(finButtonCanncel), NULL);
   gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, GTK_BORDER);
@@ -231,17 +209,20 @@ static GtkWidget* makeIoFrame(char *title)
 {
   GtkWidget *frame, *sub_frame;
   GtkWidget *vbox;
+  char *name;
 
   frame = gtk_frame_new(title);
   gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
 
   vbox = gtk_vbox_new(FALSE, GTK_BORDER);
 
-  sub_frame = ioPackNew((char *)_(ioLabels[0]), INPUT);
+  name = ioLabels[0];
+  sub_frame = ioPackNew(_(name), INPUT);
   gtk_box_pack_start(GTK_BOX(vbox), sub_frame, FALSE, TRUE, 0);
   gtk_widget_show(sub_frame);
   
-  sub_frame = ioPackNew((char *)_(ioLabels[1]), OUTPUT);
+  name = ioLabels[1];
+  sub_frame = ioPackNew(_(name), OUTPUT);
   gtk_box_pack_start(GTK_BOX(vbox), sub_frame, FALSE, TRUE, 0);
   gtk_widget_show(sub_frame);
   
@@ -259,6 +240,14 @@ static GtkWidget* makePaperFrame(char *title)
   GtkWidget *frame;
   GtkWidget *vbox;
   GtkWidget *hbox;
+  GtkWidget *button;
+  double param_scale[] = { 10.0, 400.0, 10.0, 100.0, 0.0 };
+
+#ifdef CONV_VERSION2
+  GtkWidget *frame2;
+  GtkWidget *hbox2;
+  double param_margin[] = {0.0, 1000.0, 1.0, 100.0, 0.0 };
+#endif /* CONV_VERSION2 */
 
   frame = gtk_frame_new(title);
   gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
@@ -269,57 +258,20 @@ static GtkWidget* makePaperFrame(char *title)
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show(hbox);
 
+#ifdef ROLL_PAPER
   hbox = selectPackNew(NULL, (char**)binEntry, P_BIN);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show(hbox);
 
-  hbox = selectPackNew(NULL, (char**)autoCutEntry, P_AUTO_CUT);
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
-  gtk_widget_show(hbox);
-
-  gtk_container_add(GTK_CONTAINER(frame), vbox);
-  gtk_widget_show(vbox);
-
-  gtk_container_set_border_width (GTK_CONTAINER (frame), GTK_BORDER);
-  return frame;
-}
-
-
-static GtkWidget* makeLayoutFrame (char *title)
-{
-  GtkWidget *frame, *frame2;
-  GtkWidget *vbox;
-  GtkWidget *hbox;
-  GtkWidget *button;
-  double param_scale[] = { 10.0, 400.0, 10.0, 100.0, 0.0 };
-
-#ifdef CONV_VERSION2
-  GtkWidget *hbox2;
-  double param_margin[] = {0.0, 1000.0, 1.0, 100.0, 0.0 };
-#endif /* CONV_VERSION2 */
-
-  frame = gtk_frame_new(title);
-  gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
-
-  vbox = gtk_vbox_new(FALSE, GTK_BORDER);
-
-  /* Fit to Page setup */
-  hbox = checkPackNew(NULL, P_FIT_PAGE);
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
-  gtk_widget_show(hbox);
-
-  /* Scale setup */
+#endif /* ROLL_PAPER */
   hbox = spinPackNew(NULL, P_SCALE, param_scale);
   gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show(hbox);
 
-  /* Margin setup */
 #ifdef CONV_VERSION2
   frame2 = gtk_frame_new(commonLabelCall(P_MARGIN, NULL));
   gtk_frame_set_shadow_type(GTK_FRAME(frame2), GTK_SHADOW_ETCHED_IN);
 
-  margin_frame_ = frame2; /* add Thu Oct 18 2001 */
-
   hbox = gtk_hbox_new(TRUE, GTK_BORDER);
 
   hbox2 = spinPackNew (NULL, P_MARGIN_X, param_margin);
@@ -341,11 +293,6 @@ static GtkWidget* makeLayoutFrame (char *title)
   gtk_widget_show(frame2);
 #endif /* CONV_VERSION2 */
 
-/* Multi Page setup */
-  frame2 = radioPackNew(NULL, (char**)multiPageEntry, P_MULTI_PAGE);
-  gtk_box_pack_start(GTK_BOX(vbox), frame2, FALSE, TRUE, 0);
-  gtk_widget_show(frame2);
-
   gtk_container_add(GTK_CONTAINER(frame), vbox);
   gtk_widget_show(vbox);
 
@@ -353,46 +300,50 @@ static GtkWidget* makeLayoutFrame (char *title)
   return frame;
 }
 
+
+
 static GtkWidget* makeAdvancedFrame(char *title)
 {
   GtkWidget *frame, *sub_frame;
-  GtkWidget *table, *hbox;
+  GtkWidget *vbox;
+  GtkWidget *hbox, *hwbox;
 
   frame = gtk_frame_new(title);
   gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
 
-  table = gtk_table_new (6, 2, FALSE);
+  vbox = gtk_vbox_new(FALSE, GTK_BORDER);
 
   hbox = selectPackNew(NULL, (char**)mediaTypeEntry, P_MEDIA_TYPE);
-  gtk_table_attach (GTK_TABLE(table), hbox, 0, 2, 0, 1, GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL | GTK_SHRINK | GTK_EXPAND, 0, 0); 
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show(hbox);
   
   hbox = selectPackNew(NULL, (char**)halftoneEntry, P_HALF_TONE);
-  gtk_table_attach (GTK_TABLE(table), hbox, 0, 2, 1, 2, GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL | GTK_SHRINK | GTK_EXPAND, 0, 0); 
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show(hbox);
 
   hbox = selectPackNew(NULL, (char**)resolutionEntry, P_RESOLUTION);
-  gtk_table_attach (GTK_TABLE(table), hbox, 0, 2, 2, 3, GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL | GTK_SHRINK | GTK_EXPAND, 0, 0); 
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show(hbox);
 
   hbox = selectPackNew(NULL, (char**)levelEntry, P_QUALITY_LEVEL);
-  gtk_table_attach (GTK_TABLE(table), hbox, 0, 2, 3, 4, GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL | GTK_SHRINK | GTK_EXPAND, 0, 0); 
+  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show(hbox);
 
-  hbox = checkPackNew(NULL, P_MICRO_WEAVE);
-  gtk_table_attach (GTK_TABLE(table), hbox, 0, 1, 4, 5, GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL | GTK_SHRINK | GTK_EXPAND, 0, 0); 
-  gtk_widget_show(hbox);
+  hwbox =gtk_hbox_new (FALSE, 10);
 
   hbox = checkPackNew(NULL, P_HIGH_SPEED);
-  gtk_table_attach (GTK_TABLE(table), hbox, 0, 1, 5, 6, GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL | GTK_SHRINK | GTK_EXPAND, 0, 0); 
+  gtk_box_pack_start(GTK_BOX(hwbox), hbox, FALSE, TRUE, 0);
   gtk_widget_show(hbox);
 
   sub_frame = radioPackNew(NULL, (char**)inkEntry, P_INK);
-  gtk_table_attach (GTK_TABLE(table), sub_frame, 1, 2, 4, 6, GTK_FILL | GTK_SHRINK | GTK_EXPAND, GTK_FILL | GTK_SHRINK | GTK_EXPAND, 0, 0); 
+  gtk_box_pack_start(GTK_BOX(hwbox), sub_frame, FALSE, TRUE, 0);
   gtk_widget_show(sub_frame);
 
-  gtk_container_add(GTK_CONTAINER(frame), table);
-  gtk_widget_show(table);
+  gtk_box_pack_start(GTK_BOX(vbox), hwbox, FALSE, TRUE, 0);
+  gtk_widget_show(hwbox);
+
+  gtk_container_add(GTK_CONTAINER(frame), vbox);
+  gtk_widget_show(vbox);
 
   gtk_container_set_border_width (GTK_CONTAINER (frame), GTK_BORDER);
   return frame;
@@ -446,22 +397,19 @@ static GtkWidget* makePropertyNotebook(void)
 
   notebook = gtk_notebook_new();
   gtk_notebook_set_tab_pos (GTK_NOTEBOOK(notebook), GTK_POS_TOP);
-  for(i = 1; i < 7; i++){
-    name = (char *)_(highRanckLabels[i]);
+  for(i = 1; i < 5; i++){
+    name = _(highRanckLabels[i]);
     label = gtk_label_new(name);
     switch(i){
-    case 1: page = makeIoFrame (name); break;
-    case 2: page = makePaperFrame (name); break;
-    case 3: page = makeLayoutFrame (name); break;
-    case 4: page = makeAdvancedFrame (name); break;
-    case 5: page = makeColorManagementFrame (name); break;
-    case 6: page = makeUtilFrame (name); break;
+    case 1: page = makeIoFrame(name); break;
+    case 2: page = makePaperFrame(name); break;
+    case 3: page = makeAdvancedFrame(name); break;
+    case 4: page = makeColorManagementFrame(name); break;
     default: return NULL;
     }
     gtk_widget_show(label);
     gtk_widget_show(page);
     gtk_notebook_append_page( GTK_NOTEBOOK(notebook), page, label);
-
   }
   return notebook;
 }
@@ -474,8 +422,8 @@ static GtkWidget* makePropertyNotebook(void)
 
 void confWinInit(int *argc, char **argv[], char *filename, SEP_INIT_PARAM *sepip, PIPS_INIT_PARAM *pip)
 {
-  int i;
-  FILE *fp;
+	FILE *fp;
+	int i;
 
   gtk_set_locale();
   gtk_init(argc, argv);
@@ -520,40 +468,20 @@ void confWinInit(int *argc, char **argv[], char *filename, SEP_INIT_PARAM *sepip
     case P_STRENGTH_YELLOW:
     case P_MARGIN_X:
     case P_MARGIN_Y:
-#ifdef INK_CHANGE_SYSTEM
-    case P_INKSET:
-#endif /* INK_CHANGE_SYSTEM */
       options[i] = (int *)malloc(sizeof(int)); break;
     default:  options[i] = NULL; break;
     }
   }
-
   input_file = (char *)calloc(1024, sizeof(char));
-  strcpy(input_file, filename);
-
   output_file = (char *)calloc(1024, sizeof(char));
-  strcpy(output_file, "Output.prn");
-
-  if (pip->atbmp_fifo_path)
-  {
-	  atinput_file = (char *)calloc(1024, sizeof(char));
-	  strcpy(atinput_file, pip->atbmp_fifo_path);
-  }
-  else
-  {
-	  atinput_file = NULL;
-  }
-
+  strcpy(input_file, filename);
+  strcpy(output_file, "output.prn");
   output_type = 1;
   setDefaultOptions(sepip);
-
-  memset (&pips_util_pack, 0, sizeof (UTIL_PACK));
-  pips_util_pack.inkbox_xpm = inkbox_xpm_new ();
-  pips_util_pack.timer = gtk_timeout_add (1000, getInkStatus, NULL);
-  return;
 }
 
 
+
 void confWinFinalize(void)
 {
   int i;
@@ -568,7 +496,9 @@ void confWinFinalize(void)
     case P_STRENGTH_MAGENTA:
     case P_STRENGTH_YELLOW: free(options[i]);
 
+#ifdef ROLL_PAPER
     case P_BIN:
+#endif /* ROLL_PAPER */
     case P_INK:
     case P_MEDIA_SIZE:
     case P_RESOLUTION:
@@ -577,20 +507,12 @@ void confWinFinalize(void)
     case P_HALF_TONE:
     case P_HIGH_SPEED:
     case P_QUALITY_LEVEL:
-    case P_OUTPUT_EX:
-    case P_FIT_PAGE:
-    case P_MULTI_PAGE:
-    case P_AUTO_CUT:
-	    free(opt_address[i]);
+    case P_OUTPUT_EX: free(opt_address[i]);
     default: break;
     }
   }
   free(input_file);
   free(output_file);
-
-  inkbox_xpm_ref (pips_util_pack.inkbox_xpm);
-  gtk_timeout_remove (pips_util_pack.timer);
-  return;
 }
 
 
@@ -608,7 +530,7 @@ int confWinShow(SEP_INIT_PARAM *sepip, const char *wtitle)
   window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title(GTK_WINDOW(window), app_title);
   gtk_signal_connect(GTK_OBJECT(window), "delete_event", GTK_SIGNAL_FUNC(gtk_main_quit), NULL);
-  pips_util_pack.main_widget = window;
+  
   vbox = gtk_vbox_new(FALSE, 5);
 
   container = makePropertyNotebook();
@@ -622,117 +544,10 @@ int confWinShow(SEP_INIT_PARAM *sepip, const char *wtitle)
   gtk_widget_show(vbox);
 
   commonSetOptionsSensitive();
-  gtk_window_set_policy(GTK_WINDOW(window), FALSE, TRUE, FALSE);
+  gtk_window_set_policy(GTK_WINDOW(window), FALSE, FALSE, FALSE);
   gtk_widget_show(window);
 
   gtk_main();
   return 0;
 }
-
-static
-GtkWidget* makeUtilFrame (char *title)
-{
-  GtkWidget *frame, *core_frame, *vbox;
-
-  frame = gtk_frame_new(title);
-  gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_ETCHED_IN);
-  vbox = gtk_vbox_new(TRUE, GTK_BORDER);
-
-  core_frame = makeConnectFrame (NULL);
-  gtk_box_pack_start (GTK_BOX(vbox), core_frame, FALSE, TRUE, 0);
-  pips_util_pack.connect_frame = core_frame;
-
-  core_frame = makeNoConnectFrame (NULL);
-  gtk_box_pack_start (GTK_BOX(vbox), core_frame, FALSE, TRUE, 0);
-  pips_util_pack.no_connect_frame = core_frame;
-
-  gtk_container_add (GTK_CONTAINER(frame), vbox);
-  gtk_widget_show (vbox);
-
-  /*getInkStatus (NULL);*/
-
-  return frame;
-}
-
-static
-GtkWidget* makeConnectFrame(char *title)
-{
-  GtkWidget *frame, *vbox, *hbox, *prog_frame, *prog_vbox;
-
-
-  frame = gtk_frame_new(title);
-  gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_NONE);
-
-  vbox = gtk_vbox_new(FALSE, GTK_BORDER);
-
-  hbox = commandButtonNew ((char *)_(Status_Monitor));
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
-  gtk_widget_show(hbox);
-
-  hbox = commandButtonNew ((char *)_(Nozzle_Check));
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
-  gtk_widget_show(hbox);
-
-  hbox = commandButtonNew ((char *)_(Head_Cleaning));
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
-  gtk_widget_show(hbox);
-
-  hbox = commandButtonNew ((char *)_(Print_Head_Alignment));
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
-  gtk_widget_show(hbox);
-
-  hbox = commandButtonNew ((char *)_(Auto_Cutter_Adjustment));
-  gtk_box_pack_start(GTK_BOX(vbox), hbox, FALSE, TRUE, 0);
-#ifdef USE_AUTO_CUT
-  gtk_widget_show(hbox);
-#endif /* USE_AUTO_CUT */
-
-  prog_frame = gtk_frame_new((char *)_(Ink_Volume));
-  prog_vbox = gtk_vbox_new(FALSE, GTK_BORDER);
-
-#if (USE_INKBOX)
-  hbox = inkboxPackNew ();
-  gtk_box_pack_start(GTK_BOX(prog_vbox), hbox, FALSE, TRUE, 0);
-  gtk_widget_show(hbox);
-#else
-  hbox = progressPackNew ((char *)_(Ink_Black));
-  gtk_box_pack_start(GTK_BOX(prog_vbox), hbox, FALSE, TRUE, 0);
-  gtk_widget_show(hbox);
-
-  hbox = progressPackNew ((char *)_(Ink_Color));
-  gtk_box_pack_start(GTK_BOX(prog_vbox), hbox, FALSE, TRUE, 0);
-  gtk_widget_show(hbox);
-#endif
-
-#if CL700 || SC480 || SC580
-  hbox = commandButtonNew ((char *)_(Ink_Chenge));
-  gtk_box_pack_start(GTK_BOX(prog_vbox), hbox, FALSE, TRUE, 0);
-  gtk_widget_show(hbox);
-#endif
-
-  gtk_container_add(GTK_CONTAINER(prog_frame), prog_vbox);
-  gtk_widget_show(prog_vbox);
-  gtk_box_pack_start(GTK_BOX(vbox), prog_frame, FALSE, TRUE, 0);
-  gtk_widget_show(prog_frame);
-
-  gtk_container_add(GTK_CONTAINER(frame), vbox);
-  gtk_widget_show(vbox);
-
-  gtk_container_set_border_width (GTK_CONTAINER (frame), GTK_BORDER);
-  return frame;
-}
-
-static
-GtkWidget* makeNoConnectFrame(char *title)
-{
-  GtkWidget *frame, *label;
-
-  frame = gtk_frame_new(title);
-  gtk_frame_set_shadow_type(GTK_FRAME(frame), GTK_SHADOW_NONE);
-
-  label = gtk_label_new ((char *)_(No_Connect_Message));
-  gtk_container_add(GTK_CONTAINER(frame), label);
-  gtk_widget_show(label);
-  return frame;
-}
 #endif
